@@ -1,6 +1,6 @@
 /**
 \file
-\copyright Copyright 2018. Tom de Geus. All rights reserved.
+\copyright Copyright. Tom de Geus. All rights reserved.
 \license This project is released under the MIT License.
 */
 
@@ -13,15 +13,15 @@ namespace GMatElastic {
 
 namespace detail {
 
-    inline std::string unquote(const std::string& arg)
-    {
-        std::string ret = arg;
-        ret.erase(std::remove(ret.begin(), ret.end(), '\"'), ret.end());
-        return ret;
-    }
-
+inline std::string unquote(const std::string& arg)
+{
+    std::string ret = arg;
+    ret.erase(std::remove(ret.begin(), ret.end(), '\"'), ret.end());
+    return ret;
 }
 
+} // namespace detail
+
 inline std::string version()
 {
     return detail::unquote(std::string(QUOTE(GMATELASTIC_VERSION)));
@@ -33,8 +33,8 @@ inline std::vector<std::string> version_dependencies()
 
     ret.push_back("gmatelastic=" + version());
     ret.push_back("gmattensor=" + GMatTensor::version());
-    ret.push_back("xtensor=" +
-        detail::unquote(std::string(QUOTE(XTENSOR_VERSION_MAJOR))) + "." +
+    ret.push_back(
+        "xtensor=" + detail::unquote(std::string(QUOTE(XTENSOR_VERSION_MAJOR))) + "." +
         detail::unquote(std::string(QUOTE(XTENSOR_VERSION_MINOR))) + "." +
         detail::unquote(std::string(QUOTE(XTENSOR_VERSION_PATCH))));
 
